"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSocket = exports.usePresence = exports.useChannel = exports.Provider = exports.Consumer = void 0;

var React = _interopRequireWildcard(require("react"));

var _phoenix = require("phoenix");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const PhoenixContext = /*#__PURE__*/React.createContext({});
PhoenixContext.displayName = 'Phoenix';

const Provider = ({
  url = '/socket',
  params = {},
  children
}) => {
  const [socket, setSocket] = React.useState(null);
  React.useEffect(() => {
    const socket = new _phoenix.Socket(url, {
      params
    });
    socket.connect();
    setSocket(socket);
  }, []);
  return /*#__PURE__*/React.createElement(PhoenixContext.Provider, {
    value: {
      socket,
      setSocket
    }
  }, children);
};

exports.Provider = Provider;
const Consumer = PhoenixContext.Consumer;
exports.Consumer = Consumer;

const useSocket = () => {
  const ctx = React.useContext(PhoenixContext);
  const {
    socket
  } = ctx;
  return socket;
};

exports.useSocket = useSocket;

const useChannel = (topic, params = {}) => {
  const socket = useSocket();
  if (!socket) return null;
  const c = socket.channels.find(c => c.topic === topic);
  const channel = c ? c : socket.channel(topic, params);
  return channel;
};

exports.useChannel = useChannel;

const usePresence = topic => {
  const presence = React.useMemo(() => {
    const channel = useChannel(topic);
    if (!channel) return null;
    return new _phoenix.Presence(channel);
  }, [topic]);
  return presence;
};

exports.usePresence = usePresence;